@@ -29,7 +29,7 @@ def parse_filter_string(input_filters: Union[str, dict]) -> Dict[str, any]:
   if isinstance(input_filters, str):
     return dict(
       [x.split('=') if '=' in x else [x, None]
-      for x in input.split(',')])
+      for x in input_filters.split(',')])
   return input_filters
 
 
